==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/gfx/mod-gl/gl-hud/gl-tactical/gl-tactical.h <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6GFX_MOD_GL_HUD_TACTICAL_H
#define LIQUIDWAR6GFX_MOD_GL_HUD_TACTICAL_H

#include "../../../gfx.h"
#include "../../gl-utils/gl-utils.h"
#include "../gl-hud.h"

extern MOD_GL_HUD_BACKEND
  * mod_gl_hud_tactical_create_backend (MOD_GL_UTILS_CONTEXT * utils_context);

/*
 * In display.c
 */
extern void mod_gl_hud_tactical_display (MOD_GL_UTILS_CONTEXT *
					 utils_context, void *hud_context,
					 LW6KER_GAME_STATE * game_state,
					 LW6GFX_HUD_STEP step);
extern void mod_gl_hud_tactical_display_preview (MOD_GL_UTILS_CONTEXT *
						 utils_context,
						 void *hud_context,
						 LW6GFX_HUD_STEP step);

/*
 * In setup.c
 */
extern void *mod_gl_hud_tactical_init (MOD_GL_UTILS_CONTEXT * utils_context);
extern void mod_gl_hud_tactical_quit (MOD_GL_UTILS_CONTEXT *
				      utils_context, void *hud_context);

#endif

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/gfx/mod-gl/gl-hud/gl-tactical/gl-tactical.h <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6GFX_MOD_GL_HUD_TACTICAL_H
#define LIQUIDWAR6GFX_MOD_GL_HUD_TACTICAL_H

#include "../../../gfx.h"
#include "../../gl-utils/gl-utils.h"
#include "../gl-hud.h"

extern MOD_GL_HUD_BACKEND
  * mod_gl_hud_tactical_create_backend (MOD_GL_UTILS_CONTEXT * utils_context);

/*
 * In display.c
 */
extern void mod_gl_hud_tactical_display (MOD_GL_UTILS_CONTEXT *
					 utils_context, void *hud_context,
					 LW6KER_GAME_STATE * game_state,
					 LW6GFX_HUD_STEP step);
extern void mod_gl_hud_tactical_display_preview (MOD_GL_UTILS_CONTEXT *
						 utils_context,
						 void *hud_context,
						 LW6GFX_HUD_STEP step);

/*
 * In setup.c
 */
extern void *mod_gl_hud_tactical_init (MOD_GL_UTILS_CONTEXT * utils_context);
extern void mod_gl_hud_tactical_quit (MOD_GL_UTILS_CONTEXT *
				      utils_context, void *hud_context);

#endif
